      subroutine ico_calcphimax (theta, phimax)

C     Calculate the maximum allowable value of the angle phi in the
C     icosahedral asymmetic unit for a given value of theta. Calculation
C     is based on spherical triognometry relations described in CRC
C     Standard Mathematical Tables
C
C     Define a spherical triangle (on surface of a sphere) made up of
C     three sides (a,b,c) and opposite each side are three angles
C     (A,B,C). All side and angle measurements are in degrees. Each side
C     is an arc of a great circle. For the edge of the icosahedral
C     asymmetric unit between the 3-fold and 5-fold axes, the angle and
C     side lengths are as follows
C
C     a = final latitude (theta) = 90.0                         
C     b = initial latitude (theta) = 69.1                         
C     c = arc between 3-fold and 5-fold axis                         
C     
C     A = initial bearing (at 3-fold axis)                         
C     B = final reverse bearing (at 5-fold axis)                   
C     C = change in longitude (phi) = 31.7                         
C
C     D. Belnap, purdue university vax 4000/90 and dec 3000, december 1993
C     R. Sinkovits, 19-Jul-2006 Minor cleanup and commenting

      implicit none

      real*4, intent(in) :: theta
      real*4, intent(out) :: phimax

      real*4  a,b,c, small_a,small_b, a_minus_b, a_plus_b
      real*4  temp
      real*8  deg_to_rad, rad_to_deg

C     Values below generated by subroutine geometry_init using the
C     following equations
C        TAU = (1.0 + SQRT(5.0)) / 2
C        TEMP = TAU / SQRT(3.0)
C        small_b = 90.0 - ACOSD(TEMP)
C        TEMP = 1/TAU
C        C = ATAND(TEMP)
      parameter  (small_b = 69.09484255211070)  ! theta for 3-fold axis
      parameter  (c       = 31.71747441146101)  ! phi for 5-fold axis

      deg_to_rad = acos(-1.0d0)/180.0d0
      rad_to_deg = 1.0d0/deg_to_rad

      small_a = 90.0

C     To calculate A, the initial bearing from 3-fold to 5-fold axis and
c     B, the final reverse bearing, solve for A & B with napier's
C     analogies
C
C             temp = tan[(A-B)/2], then temp = tan[(A+B)/2]                  
C
C     To calculate C, the distance (in degrees) from 3-fold to 5-fold
C     axis, use gauss's formula
C
C            sin[C/2] = ( sin[(a+b)/2]sin[C/2] ) / cos[(A-B)/2]  
C
C     Only A and B are needed for the phimax calculation.

      temp = (1/tan(c*deg_to_rad/2.0))  * 
     1      (sin((small_a-small_b)*deg_to_rad/2.0)/ 
     2     sin((small_a+small_b)*deg_to_rad/2.0)) 
      a_minus_b = 2*rad_to_deg*atan(temp) 
      temp = (1/tan(c*deg_to_rad/2.0))  * 
     1      (cos((small_a-small_b)*deg_to_rad/2.0)/ 
     2     cos((small_a+small_b)*deg_to_rad/2.0)) 
      a_plus_b = 2*rad_to_deg*atan(temp) 
      b = (a_plus_b - a_minus_b) / 2.0
      a = a_minus_b + b

C     Calculate phimax for theta (a)
C     Calculate B, use law of sines  temp = sin(B)
C     Calculate C (phimax), use Napier's analogies temp = tan(C/2)

      small_a = theta
      temp    = sin(a*deg_to_rad)*sin(small_b*deg_to_rad) / 
     1     sin(small_a*deg_to_rad) 
      b       = rad_to_deg*asin(temp) 
      temp    = sin((small_a-small_b)*deg_to_rad/2.0)  / 
     1        ( sin((small_a+small_b)*deg_to_rad/2.0) *  
     2     tan((a-b)*deg_to_rad/2.0) ) 
      phimax  = 2*rad_to_deg*atan(temp)

      return
      end subroutine ico_calcphimax

